@@ -1,21 +1,20 @@
-import lazy_import
-
-import sys
 import base64
 import binascii
-import pathlib
-import webbrowser
-import logging
 import inspect
 import io
 import itertools
+import logging
+from pathlib import Path
 import subprocess
-from importlib.machinery import SourceFileLoader
+import sys
+import webbrowser
 from configparser import ConfigParser
-from urllib.parse import urljoin
+from importlib.machinery import SourceFileLoader
 from pprint import pformat
-from typing import Any, Tuple, List, Union
+from typing import Any, List, Mapping, Tuple, Union
+from urllib.parse import urljoin
 
+import lazy_import
 import pyperclip
 import ujson
 
@@ -23,7 +22,7 @@ jsonpickle = lazy_import.lazy_module("jsonpickle")
 import regex as re
 from decorator import decorator
 
-from .modules.internal.colors import yellow, cyan, green, magenta, blue, red
+from .modules.internal.colors import blue, cyan, green, magenta, red, yellow
 
 
 class ChepyDecorators(object):
@@ -48,7 +47,7 @@ class ChepyDecorators(object):
         func_sig["args"] = func_arguments
         func_self._stack.append(func_sig)
 
-        return func(*args, **kwargs)
+        return func(*args, **kwargs)  # lgtm [py/call-to-non-callable]
 
 
 class ChepyCore(object):
@@ -152,7 +151,7 @@ class ChepyCore(object):
         Returns:
             object: Path object
         """
-        return pathlib.Path(path).expanduser().absolute()
+        return Path(path).expanduser().absolute()
 
     def _info_logger(self, data: str) -> None:
         """Just a binding for logger.info
@@ -797,7 +796,7 @@ class ChepyCore(object):
         Returns:
             Chepy: The Chepy object.
         """
-        files = [x for x in pathlib.Path(self.state).glob(pattern) if x.is_file()]
+        files = [x for x in Path(self.state).glob(pattern) if x.is_file()]
         self.states = {x[0]: str(x[1]) for x in enumerate(files) if x[1].is_file()}
         return self
 
@@ -816,7 +815,7 @@ class ChepyCore(object):
             >>> # at the moment, the state only contains the string "/path/to/file"
             >>> c.load_file() # this will load the file content into the state
         """
-        path = pathlib.Path(str(self.state)).expanduser().absolute()
+        path = Path(str(self.state)).expanduser().absolute()
         if binary_mode:
             with open(path, "rb") as f:
                 self.states[self._current_index] = bytearray(f.read())
@@ -867,6 +866,31 @@ class ChepyCore(object):
         self._info_logger("File written to {}".format(self._abs_path(path)))
         return None
 
+    def run_recipe(self, recipes: List[Mapping[str, Union[str, Mapping[str, Any]]]]):
+        """Run a recipe on the state. All arguments including optional needs to
+        be specified for a recipe.
+
+        Args:
+            recipes (List[Mapping[str, Union[str, Mapping[str, Any]]]]): An array of recipes.
+                Recipes are in the format {'function': 'function_name', 'args': {'arg_name': 'arg_val'}}
+
+        Returns:
+            Chepy: The Chepy object.
+
+        Examples:
+            >>> c = Chepy('bG9sCg==').run_recipe([{"function":"base64_decode","args":{"custom":None,"fix_padding":True}}]])
+            >>> lol
+            In this example, we are calling the base64 decode method on the state.
+        """
+        for recipe in recipes:
+            function = recipe["function"]
+            args = recipe["args"]
+            if len(args) > 0:
+                getattr(self, function)(**args)
+            else:
+                getattr(self, function)()
+        return self
+
     def save_recipe(self, path: str):
         """Save the current recipe
 
@@ -970,7 +994,7 @@ class ChepyCore(object):
         )
 
         for _ in range(int(iterations)):
-            d = getattr(self, callback)(**args)
+            getattr(self, callback)(**args)
 
         self._stack = self._stack[: stack_loop_index + 1]
         return self
@@ -1168,7 +1192,7 @@ class ChepyCore(object):
             None
         """
         assert enable in ["true", "false"], "Valid values are true and false"
-        conf_path = pathlib.Path().home() / ".chepy" / "chepy.conf"
+        conf_path = Path().home() / ".chepy" / "chepy.conf"
         c = ConfigParser()
         c.read(conf_path)
         c.set("Plugins", "enableplugins", enable)
@@ -1200,7 +1224,7 @@ class ChepyCore(object):
         """
         expand_path = self._abs_path(path)
         if expand_path.exists():
-            conf_path = pathlib.Path().home() / ".chepy" / "chepy.conf"
+            conf_path = Path().home() / ".chepy" / "chepy.conf"
             c = ConfigParser()
             c.read(conf_path)
             c.set("Plugins", "pluginpath", str(expand_path))
