@@ -1,10 +1,14 @@
 import binascii
 import statistics
+from typing import TypeVar
 
 from ..core import ChepyCore, ChepyDecorators
 from .exceptions import StateNotList
 
 
+AritmeticLogicT = TypeVar("AritmeticLogicT", bound="AritmeticLogic")
+
+
 class AritmeticLogic(ChepyCore):
     def __init__(self, *data):
         super().__init__(*data)
@@ -16,12 +20,12 @@ class AritmeticLogic(ChepyCore):
             return n
 
     @ChepyDecorators.call_stack
-    def str_bit_shift_right(self, amount: int):
+    def str_bit_shift_right(self, amount: int) -> AritmeticLogicT:
         """Bit shift string right
-        
+
         Args:
             amount (int): Amount to shift
-        
+
         Returns:
             Chepy: The Chepy object
         """
@@ -31,14 +35,14 @@ class AritmeticLogic(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def add(self, n: int):
+    def add(self, n: int) -> AritmeticLogicT:
         """Add a number to the state
-        
+
         Args:
             n (int): Number to add with
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         if not isinstance(self.state, int):
             self.state = self.__hex_to_int(self.state)
@@ -46,14 +50,14 @@ class AritmeticLogic(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def subtract(self, n: int):
+    def subtract(self, n: int) -> AritmeticLogicT:
         """Subtract a number to the state
-        
+
         Args:
             n (int): Number to subtract with
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         if not isinstance(self.state, int):
             self.state = self.__hex_to_int(self.state)
@@ -61,14 +65,14 @@ class AritmeticLogic(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def multiply(self, n: int):
+    def multiply(self, n: int) -> AritmeticLogicT:
         """Multiply a number to the state
-        
+
         Args:
             n (int): Number to multiply with
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         if not isinstance(self.state, int):
             self.state = self.__hex_to_int(self.state)
@@ -76,14 +80,14 @@ class AritmeticLogic(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def divide(self, n: int):
+    def divide(self, n: int) -> AritmeticLogicT:
         """Divide a number to the state
-        
+
         Args:
             n (int): Number to divide with
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         if not isinstance(self.state, int):
             self.state = self.__hex_to_int(self.state)
@@ -91,14 +95,14 @@ class AritmeticLogic(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def power(self, n: int):
+    def power(self, n: int) -> AritmeticLogicT:
         """Convert state to the n power of
-        
+
         Args:
             n (int): Exponent
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         if not isinstance(self.state, int):
             self.state = self.__hex_to_int(self.state)
@@ -106,11 +110,11 @@ class AritmeticLogic(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def sum(self):
+    def sum(self) -> AritmeticLogicT:
         """Calculate the sum of the state
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         assert isinstance(self.state, list), StateNotList()
         numbers = list(self.__hex_to_int(x) for x in self.state)
@@ -118,11 +122,11 @@ class AritmeticLogic(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def mean(self):
+    def mean(self) -> AritmeticLogicT:
         """Calculate the mean of the state
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         assert isinstance(self.state, list), StateNotList()
         numbers = list(self.__hex_to_int(x) for x in self.state)
@@ -130,11 +134,11 @@ class AritmeticLogic(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def median(self):
+    def median(self) -> AritmeticLogicT:
         """Calculate the median of the state
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         assert isinstance(self.state, list), StateNotList()
         numbers = list(self.__hex_to_int(x) for x in self.state)
