@@ -1,13 +1,17 @@
-import io
+import binascii
 import bz2
 import gzip
+import io
 import lzma
 import tarfile
-import zlib
 import zipfile
-import binascii
+import zlib
+from typing import TypeVar
+
 from ..core import ChepyCore, ChepyDecorators
 
+CompressionT = TypeVar("CompressionT", bound="Compression")
+
 
 class Compression(ChepyCore):
     def __init__(self, *data):
@@ -17,11 +21,11 @@ class Compression(ChepyCore):
         assert mode in ["gz", "bz2", "xz", ""], "Valid modes are gz, bz2, xz"
 
     @ChepyDecorators.call_stack
-    def fix_zip_header(self):
+    def fix_zip_header(self) -> CompressionT:
         """Fix the first 4 bytes of a zip file
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         data = bytearray(binascii.hexlify(self._convert_to_bytes()))
         data[0:8] = b"504b0304"
@@ -29,12 +33,12 @@ class Compression(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def zip_info(self):
-        """Gets various information about a zip file 
+    def zip_info(self) -> CompressionT:
+        """Gets various information about a zip file
 
-        This includes information about all the files inside the 
+        This includes information about all the files inside the
         archive.
-        
+
         Returns:
             Chepy: The Chepy object.
 
@@ -56,11 +60,11 @@ class Compression(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def zip_list_files(self):
+    def zip_list_files(self) -> CompressionT:
         """Get a list of files inside the zip archive
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("some.zip").load_file().zip_list_files().o
@@ -71,17 +75,17 @@ class Compression(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def unzip_one(self, file: str, password: str = None):
+    def unzip_one(self, file: str, password: str = None) -> CompressionT:
         """Unzip one file from zipfile
 
         Use zip_list_files to get all the filenames within the zip archive
-        
+
         Args:
             file (str): Required. Path of file inside the archive
             password (str, optional): Password if zip is encrypted. Defaults to None.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> c = Chepy("/path/to/zip.zip").load_file()
@@ -98,14 +102,14 @@ class Compression(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def unzip_all(self, password: str = None):
+    def unzip_all(self, password: str = None) -> CompressionT:
         """Unzip all files from zipfile into the state
-        
+
         Args:
             password (str, optional): Password if zip is encrypted. Defaults to None.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> c = Chepy("/path/to/zip.zip").load_file()
@@ -120,14 +124,14 @@ class Compression(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def create_zip_file(self, file_name: str):
+    def create_zip_file(self, file_name: str) -> CompressionT:
         """Create a zip archive with data from state
-        
+
         Args:
             file_name (str): File name for file inside zip archive
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> c = Chepy("some data").create_zip_file()
@@ -141,14 +145,14 @@ class Compression(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def tar_list_files(self, mode: str = ""):
+    def tar_list_files(self, mode: str = "") -> CompressionT:
         """Get file information inside a tar archive
-        
+
         Args:
             mode (str, optional): Mode to open tar file as. Defaults to "".
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         self.__tar_modes(mode)
         if mode:
@@ -160,15 +164,15 @@ class Compression(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def tar_extract_one(self, filename: str, mode: str = ""):
+    def tar_extract_one(self, filename: str, mode: str = "") -> CompressionT:
         """Extract one file from inside a tar archive
-        
+
         Args:
-            filename (str): Required. File name inside archive. 
+            filename (str): Required. File name inside archive.
             mode (str, optional): Mode to open tar file as. Defaults to "".
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         self.__tar_modes(mode)
         if mode:
@@ -180,14 +184,14 @@ class Compression(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def tar_extract_all(self, mode: str = ""):
+    def tar_extract_all(self, mode: str = "") -> CompressionT:
         """Extract one file from inside a tar archive
-        
+
         Args:
             mode (str, optional): Mode to open tar file as. Defaults to "".
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         self.__tar_modes(mode)
         if mode:
@@ -199,15 +203,15 @@ class Compression(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def tar_compress(self, filename: str, mode: str = "gz"):
+    def tar_compress(self, filename: str, mode: str = "gz") -> CompressionT:
         """Compress the state into a tar compressed object.
-        
+
         Args:
             filename (str): A file name for the tar object
             mode (str, optional): Compression mode. Defaults to "gz".
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         self.__tar_modes(mode)
         if mode:
@@ -224,15 +228,15 @@ class Compression(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def gzip_compress(self, file_name: str = None):
+    def gzip_compress(self, file_name: str = None) -> CompressionT:
         """Create a gz archive with data from state
-        
+
         Args:
-            file_name (str, optional): File name for file inside zip archive. 
+            file_name (str, optional): File name for file inside zip archive.
                 Defaults to None.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> c = Chepy("some data").gzip_compress()
@@ -246,21 +250,21 @@ class Compression(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def gzip_decompress(self):
+    def gzip_decompress(self) -> CompressionT:
         """Decompress a gzip archive
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         self.state = gzip.decompress(self._convert_to_bytes())
         return self
 
     @ChepyDecorators.call_stack
-    def bzip_compress(self):
+    def bzip_compress(self) -> CompressionT:
         """Compress the state into bz2 archive
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> c = Chepy("some data").bzip_compress()
@@ -277,24 +281,24 @@ class Compression(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def bzip_decompress(self):
+    def bzip_decompress(self) -> CompressionT:
         """Decompress a bz2 archive
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         self.state = bz2.decompress(self._convert_to_bytes())
         return self
 
     @ChepyDecorators.call_stack
-    def zlib_compress(self, level: int = 9):
+    def zlib_compress(self, level: int = 9) -> CompressionT:
         """Compress using zlib
-        
+
         Args:
             level (int, optional): Level of compression. 0-9. Defaults to 9.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> Chepy("some text").zlib_compress().to_hex().o
@@ -304,11 +308,11 @@ class Compression(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def zlib_decompress(self):
+    def zlib_decompress(self) -> CompressionT:
         """Zlib decompression
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> c = Chepy("789c0580a10d000008c35ee1b9ca05c104e737b761ca5711e8039a")
@@ -321,41 +325,41 @@ class Compression(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def lzma_compress(self):
+    def lzma_compress(self) -> CompressionT:
         """Compress using xz lzma
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         self.state = lzma.compress(self._convert_to_bytes())
         return self
 
     @ChepyDecorators.call_stack
-    def lzma_decompress(self):
+    def lzma_decompress(self) -> CompressionT:
         """Decompress lzma compressed data
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         self.state = lzma.decompress(self._convert_to_bytes())
         return self
 
     @ChepyDecorators.call_stack
-    def raw_inflate(self):
+    def raw_inflate(self) -> CompressionT:
         """Raw inflate data
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         self.state = zlib.decompress(self._convert_to_bytes(), -15)
         return self
 
     @ChepyDecorators.call_stack
-    def raw_deflate(self):
+    def raw_deflate(self) -> CompressionT:
         """Raw deflate data
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         self.state = zlib.compress(self._convert_to_bytes())[2:-4]
         return self
