@@ -79,6 +79,22 @@ class DataFormat(ChepyCore):
         self.state = ujson.loads(re.sub(r"'", '"', self._convert_to_str()))
         return self
 
+    @ChepyDecorators.call_stack
+    def join(self, by: Union[str, bytes] = "") -> DataFormatT:
+        """Join a list with specified character
+
+        Args:
+            by (Union[str, bytes], optional): What to join with. Defaults to ""
+
+        Returns:
+            Chepy: The Chepy object.
+        Examples:
+            >>> Chepy(["a", "b", "c"]).join_list(":").o
+            "a:b:c"
+        """
+        self.state = by.join(self.state)
+        return self
+
     @ChepyDecorators.call_stack
     def join_list(self, by: Union[str, bytes] = "") -> DataFormatT:
         """Join a list with specified character
@@ -1029,3 +1045,26 @@ class DataFormat(ChepyCore):
         """
         self.state = self._convert_to_str().strip()
         return self
+
+    @ChepyDecorators.call_stack
+    def convert_to_nato(self, join_by: str = " ") -> DataFormatT:
+        """Convert string to NATO phonetic format.
+
+        Example: abc = Alpha Bravo Charlie
+
+        Args:
+            join_by (str, optional): [description]. Defaults to " ".
+
+        Returns:
+            Chepy: The Chepy object
+        """
+        nato_chars = Encoding.NATO_CONSTANTS_DICT
+        hold = []
+        data: str = self._convert_to_str()
+        for d in data:
+            if d.isalpha():
+                hold.append(nato_chars[d.upper()])
+            else:
+                hold.append(d)
+        self.state = join_by.join(hold)
+        return self
