@@ -1,4 +1,33 @@
 class Encoding(object):
+    NATO_CONSTANTS_DICT = {
+        "A": "Alpha",
+        "B": "Bravo",
+        "C": "Charlie",
+        "D": "Delta",
+        "E": "Echo",
+        "F": "Foxtrot",
+        "G": "Golf",
+        "H": "Hotel",
+        "I": "India",
+        "J": "Juliett",
+        "K": "Kilo",
+        "L": "Lima",
+        "M": "Mike",
+        "N": "November",
+        "O": "Oscar",
+        "P": "Papa",
+        "Q": "Quebec",
+        "R": "Romeo",
+        "S": "Sierra",
+        "T": "Tango",
+        "U": "Uniform",
+        "V": "Victor",
+        "W": "Whiskey",
+        "X": "Xray",
+        "Y": "Yankee",
+        "Z": "Zulu",
+    }
+
     py_encodings = [
         "ascii",
         "big5",
@@ -459,4 +488,3 @@ class PcapUSB:
         "37": ">",
         "38": "?",
     }
-
