@@ -1,6 +1,6 @@
 import difflib
 from collections import OrderedDict
-from typing import Any, TypeVar, Union
+from typing import TypeVar, Union
 
 import chepy.modules.internal.colors as _int_colors
 import exrex
@@ -153,8 +153,21 @@ class Utils(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def split_by(self, pattern: str = "\n", trim=True) -> UtilsT:
-        """Split a string by the given pattern
+    def split_by_char(self, delimiter: str = " ") -> UtilsT:
+        """Split a string by a delimiter
+
+        Args:
+            delimiter (str, optional): Delimiter to split by. Defaults to " ".
+
+        Returns:
+            UtilsT: The Chepy object.
+        """
+        self.state = self._convert_to_str().split(delimiter)
+        return self
+
+    @ChepyDecorators.call_stack
+    def split_by_regex(self, pattern: str = "\n", trim=True) -> UtilsT:
+        """Split a string by the given regex pattern
 
         Args:
             pattern (str, optional): Pattern to split by. Defaults to '\\n'.
@@ -402,6 +415,45 @@ class Utils(ChepyCore):
         self.state = self.state[start:end]
         return self
 
+    @ChepyDecorators.call_stack
+    def strip_ansi(self) -> UtilsT:
+        """Strip ANSI escape codes from string
+
+        Returns:
+            Chepy: The Chepy object.
+
+        Examples:
+            >>> Chepy("\033[31mThis is a string\033[0m").strip_ansi().o
+            "This is a string"
+        """
+        self.state = re.sub(
+            "[\u001B\u009B][[\\]()#;?]*(?:(?:(?:[a-zA-Z\\d]*(?:;[a-zA-Z\\d]*)*)?\u0007)|(?:(?:\\d{1,4}(?:;\\d{0,4})*)?[\\dA-PRZcf-ntqry=><~]))",
+            "",
+            self._convert_to_str(),
+        )
+        return self
+
+    @ChepyDecorators.call_stack
+    def strip(self, pattern: str, ignore_case=True) -> UtilsT:
+        """Strip matched pattern
+
+        Args:
+            pattern (str): Required. Pattern to search
+            ignore_case (bool, optional): Case insensitive. Defaults to True.
+
+        Returns:
+            Chepy: The Chepy object.
+
+        Examples:
+            >>> Chepy("some some data").strip(r"some\s").o
+            "data"
+        """
+        flags = 0
+        if ignore_case:
+            flags = re.IGNORECASE
+        self.state = re.sub(pattern, "", self._convert_to_str(), flags=flags)
+        return self
+
     @ChepyDecorators.call_stack
     def find_replace(self, pattern: str, repl: str, ignore_case=True) -> UtilsT:
         """Replace matched pattern with repln
